# TPLSp 1.0.2

Python Package for using Thresholded Partial Least Squares (TPLS) for big data regression and classification.
It is developed with whole-brain neuroimaging (fMRI) MVPA predictors in mind. TPLS uses analytical calulations
of partial least squares to dramatically speed-up the training of models with large number of features (~millions).

Citation: Lee, S., Bradlow, E. T., & Kable, J. W. (2022). Fast construction of interpretable whole-brain decoders. Cell Reports Methods, 100227.